enumStatementRule
enum StatementRule: string
Public API: explicitly declared with
@visibility public.Statement start rules available to MySQL SQL generation.
array_column(\SqlFaker\MySql\Generation\StatementRule::cases(), 'name') // => ['Select', 'Insert', 'Update', 'Delete', 'CreateTable', 'AlterTable', 'DropTable', 'SimpleStatement']\SqlFaker\MySql\StatementType::Select === \SqlFaker\MySql\Generation\StatementRule::Select // => trueCases
case Select = 'select_stmt'Public API: explicitly declared with
@visibility public.case Insert = 'insert_stmt'Public API: explicitly declared with
@visibility public.case Update = 'update_stmt'Public API: explicitly declared with
@visibility public.case Delete = 'delete_stmt'Public API: explicitly declared with
@visibility public.case CreateTable = 'create_table_stmt'Public API: explicitly declared with
@visibility public.case AlterTable = 'alter_table_stmt'Public API: explicitly declared with
@visibility public.case DropTable = 'drop_table_stmt'Public API: explicitly declared with
@visibility public.case SimpleStatement = 'simple_statement'Public API: explicitly declared with
@visibility public.Test cases 4
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 2
Other tests reaching this symbol 2
Relations
Constant reads 1
- class-const packages/sql-faker/src/MySql/StatementType.php packages/sql-faker/src/MySql/StatementType.php:12